#!/bin/bash

# determines the relevant related branch for git submodules

wdd=`dirname $0`
MAIN_BRANCH=legacy_0.2.8
